Description Usage Format Details
To illustrate how the annolite HTML widget can be used for evaluating a
topic model, i.e. for inspecting documents where a topic is present among the
m first topics, the package includes a set of UN General Assembly speeches
(presumably) addressing migration affairs (object
unga_migrationspeeches_fulltext) and an annotationstable (object
unga_migrationspeeches_anntationstable) to highlight tokens indicative of
the migration topic.
1 2 3 |
The object unga_migrationspeeches_fulltext is a fulltexttable,
see the documentation of the function fulltexttable for an explanation
of the data structure of the class fulltexttable.
The object unga_migrationspeeches_anntationstable is a
anntationstable, see the documentation of the function anntationstable
for an explanation of the data structure of the class anntationstable.
To inspect the code that has been used to prepare the object, see the file 'unga_topicmodelling.R' in the data-raw subdirectory of the package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.